"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const core_1 = require("@angular-devkit/core");
const path_1 = require("path");
function setupOptions(options) {
    const classifiedName = core_1.strings.classify(options.name || 'test');
    const isConnected = options.connected === 'true';
    const isScssIncluded = options.scss === 'true';
    return Object.assign({}, options, { classifiedName, connectorName: options.connectorName || `${classifiedName}Connector`, isConnected,
        isScssIncluded, propInterfaceName: options.propInterfaceName || `I${classifiedName}Props`, propInputInterfaceName: options.propInputInterfaceName || `I${classifiedName}InputProps`, propDispatchInterfaceName: options.propDispatchInterfaceName || `I${classifiedName}DispatchProps`, scssImport: isScssIncluded ? `import './${classifiedName}.scss';` : '' });
}
exports.setupOptions = setupOptions;
function addToParentBarrelIndex(options) {
    return (host) => {
        const indexPath = path_1.join(options.path, 'index.ts');
        if (host.exists(indexPath)) {
            const text = host.read(indexPath);
            const sourceText = text.toString('utf-8');
            const recorder = host.beginUpdate(indexPath);
            const importString = `'./${options.classifiedName}/${options.classifiedName}${options.isConnected
                ? '.connector' : ''}';`;
            const textToInsert = `\n`
                + `export * from `
                + importString
                + `\n`;
            recorder.insertRight(sourceText.length, textToInsert);
            host.commitUpdate(recorder);
        }
        else {
            console.warn('WARNING: No index.ts file found in the parent directory.', 'Skipping adding an export to this file.', '\n.........');
        }
        return host;
    };
}
exports.addToParentBarrelIndex = addToParentBarrelIndex;
;
function reactComponents(options) {
    return (tree, _context) => {
        const updatedOptions = setupOptions(options);
        const movePath = core_1.normalize(updatedOptions.path + '/' + updatedOptions.classifiedName);
        const templateSource = schematics_1.apply(schematics_1.url('./files'), [
            schematics_1.filter((path) => (updatedOptions.isConnected || !path.includes('.connector.ts'))),
            schematics_1.filter((path) => (updatedOptions.isScssIncluded || !path.includes('.scss'))),
            schematics_1.template(Object.assign({}, updatedOptions)),
            schematics_1.move(movePath)
        ]);
        const rule = schematics_1.chain([
            addToParentBarrelIndex(updatedOptions),
            schematics_1.mergeWith(templateSource, schematics_1.MergeStrategy.Default)
        ]);
        return rule(tree, _context);
    };
}
exports.reactComponents = reactComponents;
//# sourceMappingURL=index.js.map